# torxtools

Less generic functionalities than Phillips and Pozidriv tools.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

## Locations

  * GitLab: [https://gitlab.com/jlecomte/projects/torxtools](https://gitlab.com/jlecomte/projects/torxtools)


